<?php

function wss_shrinktheweb_settings() {
  module_load_include('inc', 'wss_shrinktheweb', 'wss_shrinktheweb_account.api');
  $aAccountInfo = wss_shrinktheweb_getAccountInfo();
  $response_status = $aAccountInfo['stw_response_status'];
  $inside_pages = $aAccountInfo['stw_inside_pages'];
  $custom_size = $aAccountInfo['stw_custom_size'];
  $full_length = $aAccountInfo['stw_full_length'];
  $custom_delay = $aAccountInfo['stw_custom_delay'];
  $custom_quality = $aAccountInfo['stw_custom_quality'];
  $custom_resolution = $aAccountInfo['stw_custom_resolution'];

  $form = array();

  $form['shrinktheweb_info'] = array(
    '#type' => 'fieldset',
    '#title' => t('ShrinkTheWeb Information'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  $form['shrinktheweb_info']['shrinktheweb_get_account'] = array(
    '#type' => 'item',
    '#title' => t('Get Account'),
    '#description' => t('You can get your "Access Key" and "Secret Key" by signing up for automated screenshots at: <a target="_blank" href="https://shrinktheweb.com/">ShrinkTheWeb</a>'),
  );
  $form['shrinktheweb_info']['shrinktheweb_referrer_list'] = array(
    '#type' => 'item',
    '#title' => t('Referrer List'),
    '#description' => t('By default, you must add your server\'s IP address to <a href="https://shrinktheweb.com/content/how-do-i-lock-my-account.html" target="_blank">ShrinkTheWeb\'s "Allowed Referrers" list</a>'),
  );
  $form['shrinktheweb_info']['shrinktheweb_important_note'] = array(
    '#type' => 'item',
    '#title' => t('Important Note'),
    '#description' => t('Website Screenshot Drupal module has the limitation of only being able to use screenshot services by downloading and saving in the background. This is the recommended way, but in rare cases; ShrinkTheWeb users may have reserved a "shared IP" if your server is shared. In this case, access may be blocked, as a free user, to avoid abuse. You may overcome this and continue to use a ShrinkTheWeb free account by using the official <a href = "https://www.drupal.org/project/shrinktheweb">ShrinkTheWeb Drupal module</a>. Thank you for understanding.'),
  );

  $form['shrinktheweb_keys'] = array(
    '#type' => 'fieldset',
    '#title' => t('ShrinkTheWeb API keys'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  $form['shrinktheweb_keys']['wss_shrinktheweb_access_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Access key'),
    '#default_value' => variable_get('wss_shrinktheweb_access_key', ''),
    '#required' => TRUE,
  );
  $form['shrinktheweb_keys']['wss_shrinktheweb_secret_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Secret key'),
    '#default_value' => variable_get('wss_shrinktheweb_secret_key', ''),
    '#required' => TRUE,
  );
  if (variable_get('wss_shrinktheweb_access_key', '') == '' || variable_get('wss_shrinktheweb_secret_key', '') == '' || $response_status != 'Success') {
    $form['shrinktheweb_keys']['shrinktheweb_status'] = array(
      '#type' => 'item',
      '#title' => t('Invalid account credentials detected'),
      '#description' => t('Please enter your account credentials and make sure they are correct'),
    );
  } else {

    $form['shrinktheweb_options'] = array(
      '#type' => 'fieldset',
      '#title' => t('ShrinkTheWeb Options'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_enable_https'] = array(
      '#type' => 'select',
      '#title' => t('Enable HTTP Secure (HTTPS)'),
      '#options' => array(
        0 => t('Disable'),
        1 => t('Enable'),
      ),
      '#default_value' => variable_get('wss_shrinktheweb_enable_https', 0),
      '#required' => TRUE,
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_inside_pages'] = array(
      '#type' => 'checkbox',
      '#title' => t('Inside Page Captures'),
      '#default_value' => $inside_pages == 1 ? TRUE : FALSE,
      '#description' => $inside_pages == 0 ? t('Upgrade required to use this feature') : t('i.e. not just homepages and sub-domains, auto selected if you have purchased this pro package'),
      '#disabled' => TRUE,
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_thumb_size'] = array(
      '#type' => 'select',
      '#title' => t('Default Thumbnail size'),
      '#options' => array(
        'mcr' => t('mcr'),
        'tny' => t('tny'),
        'vsm' => t('vsm'),
        'sm' => t('sm'),
        'lg' => t('lg'),
        'xlg' => t('xlg'),
      ),
      '#default_value' => variable_get('wss_shrinktheweb_thumb_size', 'lg'),
      '#required' => TRUE,
      '#description' => t('width: mcr 75px, tny 90px, vsm 100px, sm 120px, lg 200px, xlg 320px'),
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_thumb_size_custom'] = array(
      '#type' => 'textfield',
      '#title' => t('Custom Width'),
      '#default_value' => $custom_size == 0 && $full_length == 0 ? '' : variable_get('wss_shrinktheweb_thumb_size_custom', ''),
      '#description' => $custom_size == 0 && $full_length == 0 ? t('Upgrade required to use this feature') : t('Enter your custom image width, this will override default size'),
      '#size' => 10,
      '#disabled' => $custom_size == 1 || $full_length == 1 ? FALSE : TRUE,
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_full_size'] = array(
      '#type' => 'checkbox',
      '#title' => t('Full-Length capture'),
      '#default_value' => $full_length == 0 ? FALSE : variable_get('wss_shrinktheweb_full_size', FALSE),
      '#description' => $full_length == 0 ? t('Upgrade required to use this feature') : '',
      '#disabled' => $full_length == 1 ? FALSE : TRUE,
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_max_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Max height'),
      '#default_value' => $full_length == 0 ? '' : variable_get('wss_shrinktheweb_max_height', ''),
      '#description' => $full_length == 0 ? t('Upgrade required to use this feature') : t('use if you want to set maxheight for fullsize capture'),
      '#size' => 10,
      '#disabled' => $full_length == 1 ? FALSE : TRUE,
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_native_res'] = array(
      '#type' => 'textfield',
      '#title' => t('Native resolution'),
      '#default_value' => $custom_resolution == 0 ? '' : variable_get('wss_shrinktheweb_native_res', ''),
      '#description' => $custom_resolution == 0 ? t('Upgrade required to use this feature') : t('i.e. 640 for 640x480'),
      '#size' => 10,
      '#disabled' => $custom_resolution == 1 ? FALSE : TRUE,
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_widescreen_y'] = array(
      '#type' => 'textfield',
      '#title' => t('Widescreen resolution Y'),
      '#default_value' => $custom_resolution == 0 ? '' : variable_get('wss_shrinktheweb_widescreen_y', ''),
      '#description' => $custom_resolution == 0 ? t('Upgrade required to use this feature') : t('i.e. 900 for 1440x900 if 1440 is set for Native resolution'),
      '#size' => 10,
      '#disabled' => $custom_resolution == 1 ? FALSE : TRUE,
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_delay'] = array(
      '#type' => 'textfield',
      '#title' => t('Delay After Load'),
      '#default_value' => $custom_delay == 0 ? '' : variable_get('wss_shrinktheweb_delay', ''),
      '#description' => $custom_delay == 0 ? t('Upgrade required to use this feature') : t('max. 45'),
      '#size' => 10,
      '#disabled' => $custom_delay == 1 ? FALSE : TRUE,
    );
    $form['shrinktheweb_options']['wss_shrinktheweb_quality'] = array(
      '#type' => 'textfield',
      '#title' => t('Quality'),
      '#default_value' => $custom_quality == 0 ? '' : variable_get('wss_shrinktheweb_quality', ''),
      '#description' => $custom_quality == 0 ? t('Upgrade required to use this feature') : t('0 .. 100'),
      '#size' => 10,
      '#disabled' => $custom_quality == 1 ? FALSE : TRUE,
    );
  }

  return system_settings_form($form);
}

function wss_shrinktheweb_settings_validate($form, &$form_state) {

  $thumb_size_custom = $form_state['values']['wss_shrinktheweb_thumb_size_custom'];
  if (!empty($thumb_size_custom)) {
    if (!is_numeric($thumb_size_custom)) {
      form_set_error('wss_shrinktheweb_thumb_size_custom', t('You must enter an integer for custom thumb size.'));
    } else if ($thumb_size_custom < 0) {
      form_set_error('wss_shrinktheweb_thumb_size_custom', t('Custom thumb size must be positive.'));
    }
  }
  $max_height = $form_state['values']['wss_shrinktheweb_max_height'];
  if (!empty($max_height)) {
    if (!is_numeric($max_height)) {
      form_set_error('wss_shrinktheweb_max_height', t('You must enter an integer for maximum height.'));
    } else if ($max_height < 0) {
      form_set_error('wss_shrinktheweb_max_height', t('Maximum height must be positive.'));
    }
  }
  $native_res = $form_state['values']['wss_shrinktheweb_native_res'];
  if (!empty($native_res)) {
    if (!is_numeric($native_res)) {
      form_set_error('wss_shrinktheweb_native_res', t('You must enter an integer for native resolution.'));
    } else if ($native_res < 0) {
      form_set_error('wss_shrinktheweb_native_res', t('Native resolution must be positive.'));
    }
  }
  $widescreen_y = $form_state['values']['wss_shrinktheweb_widescreen_y'];
  if (!empty($widescreen_y)) {
    if (!is_numeric($widescreen_y)) {
      form_set_error('wss_shrinktheweb_widescreen_y', t('You must enter an integer for widescreen Y.'));
    } else if ($widescreen_y < 0) {
      form_set_error('wss_shrinktheweb_widescreen_y', t('Widescreen Y must be positive.'));
    }
  }
  $delay = $form_state['values']['wss_shrinktheweb_delay'];
  if (!empty($delay)) {
    if (!is_numeric($delay)) {
      form_set_error('wss_shrinktheweb_delay', t('You must enter an integer for delay.'));
    } else if ($delay < 0 || $delay > 45) {
      form_set_error('wss_shrinktheweb_delay', t('Delay must be between 0 and 45.'));
    }
  }
  $quality = $form_state['values']['wss_shrinktheweb_quality'];
  if (!empty($quality)) {
    if (!is_numeric($quality)) {
      form_set_error('wss_shrinktheweb_quality', t('You must enter an integer for quality.'));
    } else if ($quality < 0 || $quality > 100) {
      form_set_error('wss_shrinktheweb_quality', t('Quality must be between 0 and 100.'));
    }
  }

}