<?php

define('ACCESS_KEY', variable_get('wss_shrinktheweb_access_key', ''));
define('SECRET_KEY', variable_get('wss_shrinktheweb_secret_key', ''));

// Allows us to identify known bugs and version control.
define('VER', '2.0.7_wss_drupal7');

error_reporting(E_ALL ^ E_NOTICE);

function wss_shrinktheweb_getLegacyResponse($sSearch, $s) {
    $sRegex = '/<[^:]*:' . $sSearch . '[^>]*>[^<]*<[^:]*:StatusCode[^>]*>([^<]*)<\//';
    if (preg_match($sRegex, $s, $sMatches)) {
    	return $sMatches[1];
    }
    return false;
}

/**
* Gets file content by URL
*/
function wss_shrinktheweb_fileGetContent($sFileUrl, $aParams = array()) {
    $sParams = '?';
    foreach($aParams as $sKey => $sValue)
        $sParams .= $sKey . '=' . $sValue . '&';
    $sParams = substr($sParams, 0, -1);

    $sResult = '';
    if(function_exists('curl_init')) {
        $rConnect = curl_init();

        curl_setopt($rConnect, CURLOPT_URL, $sFileUrl . $sParams);
        curl_setopt($rConnect, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($rConnect, CURLOPT_FOLLOWLOCATION, 0);
        curl_setopt($rConnect, CURLOPT_HEADER, 0); // must be 0 or else headers will break SimpleXML parsing

        $sResult = curl_exec($rConnect);
        curl_close($rConnect);
    }
    else
        $sResult = @file_get_contents($sFileUrl . $sParams);

    return $sResult;
}

/**
 * Get Account Info and return it as array
 */
function wss_shrinktheweb_getAccountInfo() {
    $aArgs['stwaccesskeyid'] = ACCESS_KEY;
    $aArgs['stwu'] = SECRET_KEY;

    $protocol = variable_get('wss_shrinktheweb_enable_https', FALSE) ? 'https://' : 'http://';
    $sRequestUrl = $protocol . 'images.shrinktheweb.com/account.php';
    $sRemoteData = wss_shrinktheweb_fileGetContent($sRequestUrl, $aArgs);
    // check if we get no response or the maintenance string
    if ($sRemoteData == '' || $sRemoteData == 'offline') {
        $aImage = array('stw_status' => 'no_response');
        if ($sRemoteData != '') {
            $aImage['message'] = MAINTENANCE;
        }
    }
    else {
        $aResponse = wss_shrinktheweb_getAccXMLResponse($sRemoteData);
    }

    return $aResponse;
}

/**
 * store the Account XML response in an array
 */
function wss_shrinktheweb_getAccXMLResponse($sResponse) {
    if (extension_loaded('simplexml')) { // If simplexml is available, we can do more stuff!
        $oDOM = new DOMDocument;
        $oDOM->loadXML($sResponse);
        $sXML = simplexml_import_dom($oDOM);
        $sXMLLayout = 'http://www.shrinktheweb.com/doc/stwacctresponse.xsd';

        // Pull response codes from XML feed
        $aResponse['stw_response_status'] = $sXML->children($sXMLLayout)->Response->Status->StatusCode; // Response Code
        $aResponse['stw_account_level'] = $sXML->children($sXMLLayout)->Response->Account_Level->StatusCode; // Account level
        // check for enabled upgrades
        $aResponse['stw_inside_pages'] = $sXML->children($sXMLLayout)->Response->Inside_Pages->StatusCode; // Inside Pages
        $aResponse['stw_custom_size'] = $sXML->children($sXMLLayout)->Response->Custom_Size->StatusCode; // Custom Size
        $aResponse['stw_full_length'] = $sXML->children($sXMLLayout)->Response->Full_Length->StatusCode; // Full Length
        $aResponse['stw_refresh_ondemand'] = $sXML->children($sXMLLayout)->Response->Refresh_OnDemand->StatusCode; // Refresh OnDemand
        $aResponse['stw_custom_delay'] = $sXML->children($sXMLLayout)->Response->Custom_Delay->StatusCode; // Custom Delay
        $aResponse['stw_custom_quality'] = $sXML->children($sXMLLayout)->Response->Custom_Quality->StatusCode; // Custom Quality
        $aResponse['stw_custom_resolution'] = $sXML->children($sXMLLayout)->Response->Custom_Resolution->StatusCode; // Custom Resolution
        $aResponse['stw_custom_messages'] = $sXML->children($sXMLLayout)->Response->Custom_Messages->StatusCode; // Custom Messages
    } else {
        // LEGACY SUPPPORT
        $aResponse['stw_response_status'] = wss_shrinktheweb_getLegacyResponse('Status', $sRemoteData);
        $aResponse['stw_account_level'] = wss_shrinktheweb_getLegacyResponse('Account_Level', $sRemoteData); // Account level
        // check for enabled upgrades
        $aResponse['stw_inside_pages'] = wss_shrinktheweb_getLegacyResponse('Inside_Pages', $sRemoteData); // Inside Pages
        $aResponse['stw_custom_size'] = wss_shrinktheweb_getLegacyResponse('Custom_Size', $sRemoteData); // Custom Size
        $aResponse['stw_full_length'] = wss_shrinktheweb_getLegacyResponse('Full_Length', $sRemoteData); // Full Length
        $aResponse['stw_refresh_ondemand'] = wss_shrinktheweb_getLegacyResponse('Refresh_OnDemand', $sRemoteData); // Refresh OnDemand
        $aResponse['stw_custom_delay'] = wss_shrinktheweb_getLegacyResponse('Custom_Delay', $sRemoteData); // Custom Delay
        $aResponse['stw_custom_quality'] = wss_shrinktheweb_getLegacyResponse('Custom_Quality', $sRemoteData); // Custom Quality
        $aResponse['stw_custom_resolution'] = wss_shrinktheweb_getLegacyResponse('Custom_Resolution', $sRemoteData); // Custom Resolution
        $aResponse['stw_custom_messages'] = wss_shrinktheweb_getLegacyResponse('Custom_Messages', $sRemoteData); // Custom Messages
    }

    return $aResponse;
}
