<?php

define('ACCESS_KEY', variable_get('wss_shrinktheweb_access_key', ''));
define('SECRET_KEY', variable_get('wss_shrinktheweb_secret_key', ''));
define('INSIDE_PAGES', variable_get('wss_shrinktheweb_inside_pages')); // set to true if inside capturing should be allowed
define('VER', '2.0.7_wss_drupal7'); // allows us to identify known bugs and version control; DONT touch!
define('MAINTENANCE', 'ShrinkTheWeb is temporarily offline for maintenance');

error_reporting(E_ALL ^ E_NOTICE);

/**
 * Generate the request arguments.
 */
function wss_shrinktheweb_generateRequestArgs($aOptions) {
    $aArgs['stwaccesskeyid'] = ACCESS_KEY;
    $aArgs['stwu'] = SECRET_KEY;
    $aArgs['stwver'] = VER;

    // allowing internal links?
    if (INSIDE_PAGES) {
        $aArgs['stwinside'] = 1;
    }

    // If SizeCustom is specified and widescreen capturing is not activated,
    // then use that size rather than the size stored in the settings
    if (!$aOptions['FullSizeCapture'] && !$aOptions['WidescreenY']) {
        // Do we have a custom size?
        if ($aOptions['SizeCustom']) {
            $aArgs['stwxmax'] = $aOptions['SizeCustom'];
        } else {
            $aArgs['stwsize'] = $aOptions['Size'];
        }
    }

    // Use fullsize capturing?
    if ($aOptions['FullSizeCapture']) {
        $aArgs['stwfull'] = 1;
        if ($aOptions['SizeCustom']) {
            $aArgs['stwxmax'] = $aOptions['SizeCustom'];
        } else {
            $aArgs['stwxmax'] = 120;
        }
        if ($aOptions['MaxHeight']) {
            $aArgs['stwymax'] = $aOptions['MaxHeight'];
        }
    }

    // Change native resolution?
    if ($aOptions['NativeResolution']) {
        $aArgs['stwnrx'] = $aOptions['NativeResolution'];
        if ($aOptions['WidescreenY']) {
            $aArgs['stwnry'] = $aOptions['WidescreenY'];
            if ($aOptions['SizeCustom']) {
                $aArgs['stwxmax'] = $aOptions['SizeCustom'];
            } else {
                $aArgs['stwxmax'] = 120;
            }
        }
    }

    // Wait after page load in seconds
    if ($aOptions['Delay']) {
        $aArgs['stwdelay'] = intval($aOptions['Delay']) <= 45 ? intval($aOptions['Delay']) : 45;
    }

    // Use Refresh On-Demand?
    if ($aOptions['RefreshOnDemand']) {
        $aArgs['stwredo'] = 1;
    }

    // Use another image quality in percent
    if ($aOptions['Quality']) {
        $aArgs['stwq'] = intval($aOptions['Quality']);
    }

    // Use custom messages?
    if (CUSTOM_MSG_URL) {
        $aArgs['stwrpath'] = CUSTOM_MSG_URL;
    }

    return $aArgs;
}

/**
 * store the XML response in an array and generate status bits
 */
function wss_shrinktheweb_getXMLResponse($sResponse) {
    if (extension_loaded('simplexml')) { // If simplexml is available, we can do more stuff!
        $oDOM = new DOMDocument;
        $oDOM->loadXML($sResponse);
        $sXML = simplexml_import_dom($oDOM);
        $sXMLLayout = 'http://www.shrinktheweb.com/doc/stwresponse.xsd';

        // Pull response codes from XML feed
        $aResponse['thumbnail'] = $sXML->children($sXMLLayout)->Response->ThumbnailResult->Thumbnail[0];
        $aResponse['stw_action'] = $sXML->children($sXMLLayout)->Response->ThumbnailResult->Thumbnail[1];
        $aResponse['stw_response_status'] = $sXML->children($sXMLLayout)->Response->ResponseStatus->StatusCode; // HTTP Response Code
        $aResponse['stw_response_code'] = $sXML->children($sXMLLayout)->Response->ResponseCode->StatusCode; // STW Error Response
        $aResponse['stw_last_captured'] = $sXML->children($sXMLLayout)->Response->ResponseTimestamp->StatusCode; // Last Captured
        $aResponse['stw_quota_remaining'] = $sXML->children($sXMLLayout)->Response->Quota_Remaining->StatusCode; // New Reqs left for today
        $aResponse['stw_bandwidth_remaining'] = $sXML->children($sXMLLayout)->Response->Bandwidth_Remaining->StatusCode; // New Reqs left for today
        $aResponse['stw_category_code'] = $sXML->children($sXMLLayout)->Response->CategoryCode->StatusCode; // Not yet implemented
    } else {
        // LEGACY SUPPPORT
        $aResponse['stw_response_status'] = wss_shrinktheweb_getLegacyResponse('ResponseStatus', $sRemoteData);
        $aResponse['stw_response_code'] = wss_shrinktheweb_getLegacyResponse('ResponseCode', $sRemoteData);

        // check remaining quota
        $aResponse['stw_quota_remaining'] = wss_shrinktheweb_getLegacyResponse('Quota_Remaining', $sRemoteData);
        // check remaining bandwidth
        $aResponse['stw_bandwidth_remaining'] = wss_shrinktheweb_getLegacyResponse('Bandwidth_Remaining', $sRemoteData);

        // get thumbnail and status
        $aThumbnail = wss_shrinktheweb_getThumbnailStatus($sRemoteData);
        $aResponse = array_merge($aResponse, $aThumbnail);
    }

    if ($aResponse['stw_action'] == 'delivered') {
        $aResponse['exists'] = true;
    } else {
        $aResponse['exists'] = false;
    }

    if ($aResponse['stw_action'] == 'fix_and_retry') {
        $aResponse['problem'] = true;
    } else {
        $aResponse['problem'] = false;
    }

    if ($aResponse['stw_action'] == 'noretry') {
        $aResponse['error'] = true;
    } else {
        $aResponse['error'] = false;
    }

    // if we use the advanced api for free account we get an invalid request
    if ($aResponse['stw_response_code'] == 'INVALID_REQUEST') {
        $aResponse['invalid'] = true;
    } else {
        $aResponse['invalid'] = false;
    }

	// if our domain or IP is not listed in the account's "Allowed Referrers" AND "Lock to Account" is enabled, then we get this error
    if ($aResponse['stw_response_code'] == 'LOCK_TO_ACCOUNT') {
        $aResponse['locked'] = true;
    } else {
        $aResponse['locked'] = false;
    }

    return $aResponse;
}

function wss_shrinktheweb_getLegacyResponse($sSearch, $s) {
    $sRegex = '/<[^:]*:' . $sSearch . '[^>]*>[^<]*<[^:]*:StatusCode[^>]*>([^<]*)<\//';
    if (preg_match($sRegex, $s, $sMatches)) {
    	return $sMatches[1];
    }
    return false;
}

function wss_shrinktheweb_getThumbnailStatus($s) {
    $sRegex = '/<[^:]*:ThumbnailResult?[^>]*>[^<]*<[^:]*:Thumbnail\s*(?:Exists=\"((?:true)|(?:false))\")+[^>]*>([^<]*)<\//';
    if (preg_match($sRegex, $s, $sMatches)) {
        return array('stw_action' => $sMatches[1],
                     'thumbnail' => $sMatches[2]);
    }
    return false;
}

/**
* Gets file content by URL
*/
function wss_shrinktheweb_fileGetContent($sFileUrl, $aParams = array()) {
    $sParams = '?';
    foreach($aParams as $sKey => $sValue)
        $sParams .= $sKey . '=' . $sValue . '&';
    $sParams = substr($sParams, 0, -1);

    $sResult = '';
    if(function_exists('curl_init')) {
        $rConnect = curl_init();

        curl_setopt($rConnect, CURLOPT_URL, $sFileUrl . $sParams);
        curl_setopt($rConnect, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($rConnect, CURLOPT_FOLLOWLOCATION, 0);
        curl_setopt($rConnect, CURLOPT_HEADER, 0); // must be 0 or else headers will break SimpleXML parsing

        $sResult = curl_exec($rConnect);
        curl_close($rConnect);
    }
    else
        $sResult = @file_get_contents($sFileUrl . $sParams);

    return $sResult;
}
